# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

numberToBinary = function(number, binaryLength)
{
  binaryVector = rep(0, binaryLength)
  for(digitNr in 1:binaryLength)
  {
    binaryVector[digitNr] = floor(number / (2^(binaryLength-digitNr)))
    if(binaryVector[digitNr] > 1)
      stop("This number is to large to fit in ", binaryLength, " binary digits")
    number = number - (2^(binaryLength-digitNr)) * binaryVector[digitNr]
  }
  return(binaryVector)
}

.powerOf2Lookup = c(1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768, 65536, 131072, 262144)
binaryToNumber = function(binaryVector)
{
  binaryVector[is.na(binaryVector)] = 0
  return(sum(.powerOf2Lookup[1:length(binaryVector)] * rev(binaryVector)))
}
