# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

## Try to load all dependancies

if(exists("runsOnCluster"))
  .libPaths("/temp_dd/igrida-fs1/sraczyns/R")  # change the package installation folder to /temp_dd/...
                                               # (for computation on the IGRIDA cluster: using network drives,
                                               # like the home folders are slowing down the machine)

# Some packages are not installed by default and they need to be installed before first computation.
# After the first script is run, they will simply be loaded every next time.
forceLoad = function(pkgname, localpath=NULL)
{
  tryCatch(
    library(package=pkgname),
  error=function(cond) {
    cat(pkgname, "package not found, trying to install it.\n")
    if(is.null(localpath))
      install.packages(pkgname, dependencies=T, repos=c("http://piotrkosoft.net/pub/mirrors/CRAN/", "http://cran.r-project.org", "http://lib.stat.cmu.edu/R/CRAN"))
    else
      install.packages(localpath, repos=NULL)
    library(package=pkgname)  # no error during installation, so it should load fine now
  })
}
