# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

mutopiaFiles.testing = unlist(read.table("mutopiaFiles.testing.txt", stringsAsFactors=FALSE), use.names=FALSE)

calculateOptimalShift = function(filename)
{
  cat(filename, ": loading data...\n", sep="")
  processedFilename = gsub("/", "_", filename)
  processedFilename = gsub("\\.mid", "", processedFilename)
  load(paste("Processed/", processedFilename, ".txt.Rdata", sep=""))
  processedFilename = gsub("\\.", "_", processedFilename)
  load(paste("NMF/", processedFilename, ".Rdata", sep=""))

  cat(filename, ": calculating optimal shift...\n", sep="")
  lags = sapply(1:88, function(pitchNr) {
    crossCorrelation = ccf(audiodata[pitchNr,], dataMatrix[pitchNr,], plot=FALSE)
    return(crossCorrelation$lag[which.max(crossCorrelation$acf)])
  })
  
  meanLag = round(median(unlist(lags)))
  cat(meanLag, "\n")
  return(meanLag)
}

library("multicore")
results = unlist(mclapply(mutopiaFiles.testing, calculateOptimalShift))

initialSilence = function(filename)
{
  cat(filename, ": loading data...\n", sep="")
  processedFilename = gsub("/", "_", filename)
  processedFilename = gsub("\\.mid", "", processedFilename)
  load(paste("Processed/", processedFilename, ".txt.Rdata", sep=""))
  initSilence = which(diff(c(0, colSums(dataMatrix))) > 0)[1] - 1
  return(initSilence)
}

# initialSilences = unlist(mclapply(mutopiaFiles.testing, initialSilence))
