# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

mutopiaFiles.testing = unlist(read.table("mutopiaFiles.testing.txt", stringsAsFactors=FALSE), use.names=FALSE)

plotNMF = function(filename)
{
  processedFilename = gsub("/", "_", filename)
  processedFilename = gsub("\\.mid", "", processedFilename)
  cat(filename, ": plotting NMF data...\n", sep="")

  load(paste("Processed/", processedFilename, ".txt.Rdata", sep=""))
  png(paste("Plots/", processedFilename, "_GT.png", sep=""), width=ncol(dataMatrix), height=88)
  par(mar=rep(0, 4))
  image(t(dataMatrix), axes=F, col=gray.colors(256,1,0,1))
  dev.off()

  processedFilename = gsub("\\.", "_", processedFilename)
  load(paste("NMF/", processedFilename, ".Rdata", sep=""))
  png(paste("Plots/", processedFilename, "_NMF.png", sep=""), width=ncol(audiodata), height=88)
  par(mar=rep(0, 4))
  image(t(audiodata), axes=F, col=gray.colors(256,1,0,1))
  dev.off()
}

library('multicore')
results = mclapply(mutopiaFiles.testing, plotNMF)  # multi-core calculations!
