# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

library("KSNR")

source("fileList.R")

timeBasis = 2   # don't change
frameSize = 1/6
framesPerBeat = 1/frameSize

for(analyzedFile in allRwcFiles)
{
  cat(analyzedFile, "\n", sep="")
  chords = c()
  chordData = read.table(paste("/nfs/titanex/vol/son1/metiss-audio/corpora/ksn/Harmony/CSV/", analyzedFile, ".csv", sep=""), header=TRUE)
  for(labelNr in 1:nrow(chordData))
  {
    tonic = .keySignatures[chordData[labelNr, "Mode"] + 1, chordData[labelNr, "Signature"] + 8]
    if(chordData[labelNr, "Mode"] == 0)
      root = tonic + .majorDegrees[chordData[labelNr, "Degree"]]
    else
      root = tonic + .minorNaturalDegrees[chordData[labelNr, "Degree"]]
    root = root %% 12
    if(!is.na(chordData[labelNr, "Type"]) && chordData[labelNr, "Type"] == 1)  # minor chord (0 = major)
      root = root + 12
    chords = c(chords, rep(root, chordData[labelNr, "Beats"] * framesPerBeat))
  }
  # remove the initial silence to match with the MIDI data
  initialSilence = which(!is.na(chords))[1] - 1
  if(initialSilence > 0)
    chords = chords[(initialSilence+1):length(chords)]

  # truncate chords to match the MIDI data
  tryCatch({
    load(paste("Processed/", analyzedFile, ".txt.Rdata", sep=""))
    cat("Mismatch: chords", length(chords), "KSN data", ncol(dataMatrix), " (", abs(length(chords) - ncol(dataMatrix))/6, "beats )!\n")
    if(length(chords) > ncol(dataMatrix))
    {
      cat("Truncating chords from", length(chords), "to", ncol(dataMatrix), "!\n")
      chords = chords[1:ncol(dataMatrix)]
    }
    if(length(chords) < ncol(dataMatrix))
    {
      cat("Padding chords from", length(chords), "to", ncol(dataMatrix), "!\n")
      chords = c(chords, rep(NA, ncol(dataMatrix) - length(chords)))
    }
  }, error=function(cond) {})

  save(chords, file=paste("Chords/", analyzedFile, ".Rdata", sep=""))
}
