# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

timeBasis  = 2      # do not change!
frameSize  = 1/6

filenames = read.table("notefilelist.txt", stringsAsFactors=FALSE)[,1]

totalDataLength = 0
for(filename in filenames)
{
  cat(paste(rep("#", 100), collapse=""), "\n")
  cat("Preparing data for ", filename, "\n", sep="")

  cat(" → Loading notes...\n")
  notes   = read.table(paste("Notes.beat/", filename, sep=""), header=TRUE)
  minNoteOn = min(notes[,2])
  notes[,2] = notes[,2] - minNoteOn  # remove the initial silence, for some reason
  notes[,3] = notes[,3] - minNoteOn  # it is present in most files

  dataLength = ceiling(max(notes[,3]) / frameSize)
  totalDataLength = totalDataLength + dataLength
  cat(" → Preparing frame-by-frame data (", dataLength, " frames)...\n", sep="")
  dataMatrix = matrix(0, 88, dataLength)
  for(frameNr in 1:dataLength)
  {
    if((frameNr %% 10) == 0)
      cat(frameNr, " ", sep="")

    startPos = frameNr * frameSize
    endPos   = startPos + frameSize
    matchingNotes = which(((notes[, 2] >= startPos) & (notes[, 2] < endPos)) | ((notes[, 3] > startPos) & (notes[, 3] <= endPos)) | ((notes[, 2] < startPos) & (notes[, 3] > endPos)))

    activeNotes = notes[matchingNotes, 1] - 20
    activeNotes = activeNotes[activeNotes <= 88]  # let's skip the higher notes (there are few in the dataset)
    activeNotes = activeNotes[activeNotes > 0]    # and the lower notes
    dataMatrix[activeNotes, frameNr] = 1
  }
  cat("\n")

  cat(" → Saving results...\n")
  save(dataMatrix, file=paste("Processed/", filename, ".Rdata", sep=""))
}

cat("Total number of frames:", totalDataLength, "\n")
