# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

###############################################
## Code ··································· ###

cat("Loading data...\n")
load(paste("Datasets/Mutopia/NMF/", sub(".txt", "", filename), sep=""))
load(paste("Datasets/Mutopia/Processed/", filename, sep=""))
S = audiodata
if(ncol(S) > maxLength)
  S = S[,1:maxLength]
S = S^nonlinearityFactor

source("Experiments.Audio/precalculateTransitionMatrix.R", local=TRUE)
source("Experiments.Audio/precalculateOutputMatrix.R", local=TRUE)
source("Experiments.Audio/performModifiedFrontierAlgorithm.R", local=TRUE)

cat("Evaluating...\n")
evaluationMyModel = PRF.onsets(resultingMatrix, dataMatrix[,1:ncol(S)])

## Post-analysis
# Remove small breaks
#   for(colNr in 2:(ncol(resultingMatrix)-1)) for(rowNr in 1:nrow(resultingMatrix))
#   {
#     if(resultingMatrix[rowNr, colNr] == 0)
#       if((resultingMatrix[rowNr, colNr-1] == 1) && (resultingMatrix[rowNr, colNr+1] == 1))
#       {
# 	resultingMatrix[rowNr, colNr] = 1
# 	cat(rowNr, colNr, "\n")
#       }
#   }
