# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

##################################################################################################
## Determining optimal state sequence (with Frontier algorithm)

# First time slice
currIndices = getCombinationIndices(1, indexTranslator)
bernoulliPties_1 = rep(0, extNumberOfCombinations)
logPriorOnProbabilities  = log(priorOnProbabilities)
logPriorOffProbabilities = log(priorOffProbabilities)
for(nt in 1:extNumberOfCombinations)
{
  currNotes = which(reducedCombinationMatrix[currIndices[nt], ])
  if(length(currNotes) == 0)
    bernoulliPties_1[nt] = sum(logPriorOffProbabilities)
  else
    bernoulliPties_1[nt] = sum(logPriorOnProbabilities[currNotes], logPriorOffProbabilities[-currNotes])
}
A = outputPties[, 1] + bernoulliPties_1

dupa1 = matrix(NA, 64, ncol(S))
dupa1[,1] = bernoulliPties_1

C  = rep(0, extNumberOfCombinations)
CI = list()
for(timeSlice in 2:ncol(S))
{
  lastIndices = currIndices
  currIndices = getCombinationIndices(timeSlice, indexTranslator)
  B = A + t(probArray[currIndices, lastIndices])
  CI[[timeSlice - 1]] = rep(0, extNumberOfCombinations)
  for(nt in 1:extNumberOfCombinations)
  {
    tempValue = which.max(B[,nt])
    CI[[timeSlice - 1]][nt] = tempValue
    C[nt] = B[tempValue, nt]
  }
  A = C + outputPtiesFinal[, timeSlice]
  dupa1[,timeSlice] = apply(t(probArray[currIndices, lastIndices]), 2, max)
}

# Backtracing
hiddenNodes    = rep(NA, ncol(S))
combinationNrs = rep(NA, ncol(S))

hiddenNodes[ncol(S)] = which.max(A)
combinationIndices = getCombinationIndices(ncol(S), indexTranslator)
combinationNrs[ncol(S)] = combinationIndices[hiddenNodes[ncol(S)]]
for(timeSlice in (ncol(S) - 1):1)
{
  hiddenNodes[timeSlice] = CI[[timeSlice]][hiddenNodes[timeSlice + 1]]
  combinationIndices = getCombinationIndices(timeSlice, indexTranslator)
  combinationNrs[timeSlice] = combinationIndices[hiddenNodes[timeSlice]]
}

resultingMatrix = t(reducedCombinationMatrix[combinationNrs,])
