# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

#cat('Calculating output probability matrix...\n')
quantizedS[quantizedS > quantizationLevels] = quantizationLevels  # to prevent NAs (when using smoothedS for calculating the output probabilities, the values can get above the highest quantization level)
outputPties = matrix(0, extNumberOfCombinations, ncol(S))
for(timeSlice in 1:ncol(outputPties))
{
  currIndices = getCombinationIndices(timeSlice, indexTranslator)
  for(nt in 1:extNumberOfCombinations)
  {
    currNotes = which(reducedCombinationMatrix[currIndices[nt], ])
    currSilence = (1:88)[-currNotes]
    if(length(currNotes) == 0)
      outputPties[nt, timeSlice] = sum(offProbabilities[cbind(1:88, quantizedS[, timeSlice])])
    else
      outputPties[nt, timeSlice] = sum(onProbabilities[cbind(currNotes, quantizedS[currNotes, timeSlice])], offProbabilities[cbind(currSilence, quantizedS[currSilence, timeSlice])])
  }
}

#cat('Calculating Bernoulli model probabilities...\n')
bernoulliPties = matrix(0, extNumberOfCombinations, ncol(S))
logPriorOnProbabilities  = log(priorOnProbabilities)
logPriorOffProbabilities = log(priorOffProbabilities)
for(timeSlice in 1:ncol(outputPties))
{
  currIndices = getCombinationIndices(timeSlice, indexTranslator)
  for(nt in 1:extNumberOfCombinations)
  {
    currNotes = which(reducedCombinationMatrix[currIndices[nt], ])
    if(length(currNotes) == 0)
      bernoulliPties[nt, timeSlice] = sum(logPriorOffProbabilities)
    else
      bernoulliPties[nt, timeSlice] = sum(logPriorOnProbabilities[currNotes], logPriorOffProbabilities[-currNotes])
  }
}

## Weighting between the Bernoulli and the full musicological model
probArray      = (1-bernoulliFudgeFactor) * probArray

outputPtiesFinal = acousticFudgeFactor * outputPties + bernoulliFudgeFactor * bernoulliPties  # it's easier to include it here than change the performModifiedFrontierAlgorithm.R
#outputPtiesFinal = acousticFudgeFactor * outputPties
