# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Cross-entropy/crossEntropyFunctions.R")

# ################################################################################################################
# optimizeCoefficients -- general function for optimizing the log-linear interpolation coefficients
#                         for a given model structure (H, HC, D, V, P, VP, HVP, HCVP, HDVP, HCDVP)
#
optimizeCoefficients = function(crossEntropyFunction, initialValues, models="HCVP", interpolation="loglinear")
{
  cat("Performing optimization for ", models, "...\n", sep="")
  fudgeFactors = optim(par=initialValues,
      fn=function(x)
        averageLikelihoodFunction(x,
          dataset=mutopiaFiles.validation,
          models=models,
          interpolation=interpolation),
      method="L-BFGS-B", lower=rep(0, length(initialValues)))
  save(fudgeFactors, file=paste("TrainedParameters/fudgeFactors.", models, ".", interpolation, ".Rdata", sep=""))
  return(fudgeFactors)
}

## This produces a bunch of NaNs....
# averageLikelihoodFunction(c(0, 0, 5.28278, 0, 0), dataset=mutopiaFiles.validation, models="HCDVPN")
