# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

stateCount = 24

realNoteNames <- c("C", "C#", "D", "D#", "E", "F", "F#", "G", "G#", "A", "A#", "B")
realNoteNames <- c(realNoteNames, tolower(realNoteNames))

plotChordPties <- function(chordPty, main="Chord transition matrix", plotTypes=FALSE, plotChords=FALSE, plotfile="Plots/chordTransition.pdf", imageWidth=8)
{
  transtext1 <- c("", "IV→V", "", "", "I→IV, V→I", "", "I→V, IV→I", "", "", "", "")
#   X11()
  pdf(plotfile, width=imageWidth/2.54, height=imageWidth/2.54)
  par(cex=0.35)
  image(t(chordPty), col=gray.colors(256,1,0,0.03), main=main, xlab=expression(paste("Previous chord ", C[t-1])), ylab=expression(paste("Current chord ", C[t])), axes=FALSE, zlim=c(0,1))
  axis(1, at=seq(0,1,length.out=stateCount), labels=rep(realNoteNames, stateCount/24))
  axis(2, at=seq(0,1,length.out=stateCount), labels=rep(realNoteNames, stateCount/24))
  box()
  if(plotTypes)
  {
    text(0.25, 0.25, "M->M", col="dark red", cex=3)
    text(0.75, 0.25, "m->M", col="dark red", cex=3)
    text(0.25, 0.75, "m->M", col="dark red", cex=3)
    text(0.75, 0.75, "m->m", col="dark red", cex=3)
    rect(-0.5/23, -0.5/23, 11.5/23, 11.5/23, lwd=2, border="dark red")
    rect(-0.5/23, 11.5/23, 11.5/23, 23.5/23, lwd=2, border="dark red")
    rect(11.5/23, -0.5/23, 23.5/23, 11.5/23, lwd=2, border="dark red")
    rect(11.5/23, 11.5/23, 23.5/23, 23.5/23, lwd=2, border="dark red")
  }
  if(plotChords)
  {
    for(interval in 1:11)
    {
      if(transtext1[interval] != "")
      {
        lines(x=c(0, (11-interval)/23), y=c(interval/23, 11/23), col=rgb(0.7-interval/(2*11),0,0), lwd=2)
        text(x=(11-interval)/23, y=11.5/23, labels=transtext1[interval], srt=45, col=rgb(0.3, 0, 0), pos=4)
      }
    }
  }
  dev.off()
}

load("TrainedParameters/chordModel.tying.Rdata")
plotChordPties(chordPty, "Tied chord transition matrix", plotTypes=T, plotfile="Plots/chordTransition_tying.pdf")

load("TrainedParameters/chordModel.noTying.Rdata")
plotChordPties(chordPty, "Untied chord transition matrix", plotTypes=T, plotfile="Plots/chordTransition_notying.pdf")

