# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Auxiliary/binary.R")
source("Settings/training.R")

## Harmony model
load(file="TrainedParameters/harmonyModel.major.Rdata")
load(file="TrainedParameters/harmonyModel.minor.Rdata")

pianoPitches = c(10, 11, 12, rep(1:12, 7), 1)
harmonyPties = array(NA, dim=c(2, 24, 88))
for(chordNr in 1:12) for(interval in 0:11)
{
  harmonyPties[2, chordNr,   which(pianoPitches == ((chordNr + interval - 1) %% 12 + 1))] = majorPties[interval + 1]
  harmonyPties[2, chordNr+12, which(pianoPitches == ((chordNr + interval - 1) %% 12 + 1))] = minorPties[interval + 1]
}
harmonyPties[1,,] = 1 - harmonyPties[2,,]
# harmonyPties = log(harmonyPties)

## Duration model
load(file="TrainedParameters/durationModel.Rdata")
# durationPties.log = log(durationPties)
durationPties.norms  = colSums(durationPties)  # normalize
for(rowNr in 1:88)
  durationPties[, rowNr, ] = t(t(durationPties[, rowNr, ]) / durationPties.norms[rowNr,])

## Voice model
# load(file="TrainedParameters/voiceModel.Rdata")
# load(file="Results/voiceModel_MI.Rdata")
# # relevantPitches = c(-36:-1,1:36)[which((rowSums(MI.full[,,1]) + rowSums(MI.full[,,2])) >= voiceModelThreshold)]
# relevantPitches = c(-maxDistance:-1,1:maxDistance)
# voiceProb = function(activity, previousFrame, currentPitch)
# {
#   relativeRelevantPitches = currentPitch + relevantPitches
#   relativeRelevantPitches[relativeRelevantPitches <= 0] = NA
#   relativeRelevantPitches[relativeRelevantPitches > 88] = NA
#
#   previousNotes = previousFrame[relativeRelevantPitches]
#   previousNotes[is.na(previousNotes)] = 0
#
#   voicePties[binaryToNumber(previousNotes) + 1, activity + 1]
# }

## Simple voice model
load(file="TrainedParameters/voiceModel.simple.Rdata")

## Neighbour model
load(file="TrainedParameters/neighbourModel.Rdata")

## Polyphony model
load(file="TrainedParameters/polyphonyModel.Rdata")
polyphonyPties = matrix(NA, length(noteCombinationLengthProbabilities), 2)
polyphonyPties[,2] = noteCombinationLengthProbabilities
polyphonyPties[,1] = 1 - polyphonyPties[,2]
# polyphonyProb = function(activity, numberOfActivePitches)
# {
#   if(activity == 1)
#     return(noteCombinationLengthProbabilities[numberOfActivePitches+1])
#   else
#     return(1 - noteCombinationLengthProbabilities[numberOfActivePitches+1])
# }

## Chord model
load(file="TrainedParameters/chordModel.tying.Rdata")

## Output model
load(file="TrainedParameters/onProbability.Rdata")
load(file="TrainedParameters/offProbability.Rdata")
onProbability  = log(onProbability)
offProbability = log(offProbability)

## Bernoulli model
load(file="TrainedParameters/priorOnProbability.Rdata")
load(file="TrainedParameters/priorOffProbability.Rdata")

## Pitch-dependend Bernoulli model
load(file="TrainedParameters/priorOnProbabilities.Rdata")
load(file="TrainedParameters/priorOffProbabilities.Rdata")
priorOnProbabilities  = 88 * priorOnProbabilities
priorOffProbabilities = 88 * priorOffProbabilities
