# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Auxiliary/PRF.R")
source("Settings/training.R")
source("Settings/audio.R")
source("Training/probabilityDefinitions.R")
chordPty = log(chordPty)

source("Experiments.Audio/obtainAudioResults.R")

if(!exists("simplify2array"))
  simplify2array = function (x, higher = TRUE)
  {
      if (length(common.len <- unique(unlist(lapply(x, length)))) >
          1L)
          return(x)
      if (common.len == 1L)
          unlist(x, recursive = FALSE)
      else if (common.len > 1L) {
          n <- length(x)
          r <- as.vector(unlist(x, recursive = FALSE))
          if (higher && length(c.dim <- unique(lapply(x, dim))) ==
              1 && is.numeric(c.dim <- c.dim[[1L]]) && prod(d <- c(c.dim,
              n)) == length(r)) {
              iN1 <- is.null(n1 <- dimnames(x[[1L]]))
              n2 <- names(x)
              dnam <- if (!(iN1 && is.null(n2)))
                  c(if (iN1) rep.int(list(n1), length(c.dim)) else n1,
                    list(n2))
              array(r, dim = d, dimnames = dnam)
          }
          else if (prod(d <- c(common.len, n)) == length(r))
              array(r, dim = d, dimnames = if (!(is.null(n1 <- names(x[[1L]])) &
                  is.null(n2 <- names(x))))
                  list(n1, n2))
          else x
      }
      else x
  }

acousticFudgeFactors = seq(0.5, 2.0, length.out=21)
bernoulliFudgeFactors = seq(0.6, 1, length.out=20)
experimentID = 1 #c(1,2)
expFactorIdx = 6

outputFilename = paste("Results/results_", fileNr, ".Rdata", sep="")

includeRealSequence = c(FALSE, TRUE)[experimentID]
expFactor = (expFactorIdx-1)/10
cat("Training the Bernoulli model fudge factor for ", fileNr, "...\n", sep="")
if(!file.exists(outputFilename))
{
  allResults = obtainResults(acousticFudgeFactors, bernoulliFudgeFactors, 1000 + c(0,100)[experimentID] + expFactorIdx, fileNr)
  cat("Saving results...\n")
  save(allResults, file=outputFilename)
}

