# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Datasets/datasets.R")
source("Settings/training.R")
plotfile.chord = "Plots/chordModel.pdf"

chordPty  = matrix(ifelse(smoothing, 1, 0), stateCount, stateCount)
chordPty0 = rep(ifelse(smoothing, 1, 0), stateCount)

allchords = c()
for(filename in allRwcFiles)
{
  load(paste("Datasets/RWC/Chords/", filename, ".Rdata", sep=""))
  chords = chords + 1
  allchords = c(allchords, chords)

  for(framenr in 2:length(chords))
    chordPty[chords[framenr], chords[framenr-1]] = chordPty[chords[framenr], chords[framenr-1]] + 1
  chordPty0[chords[1]] = chordPty0[chords[1]] + 1
}

if(tying)
{
  for(interval in 0:11)
  {
    ptySum <- rep(0, 4)
    for(ii in 1:12)
    {
      iiplus <- (ii+interval-1)%%12+1
      ptySum[1] <- ptySum[1] + chordPty[ii, iiplus]
      ptySum[2] <- ptySum[2] + chordPty[ii+12, iiplus]
      ptySum[3] <- ptySum[3] + chordPty[ii, iiplus+12]
      ptySum[4] <- ptySum[4] + chordPty[ii+12, iiplus+12]
    }
    for(ii in 1:12)
    {
      iiplus <- (ii+interval-1)%%12+1
      chordPty[ii, iiplus]       <- ptySum[1]
      chordPty[ii+12, iiplus]    <- ptySum[2]
      chordPty[ii, iiplus+12]    <- ptySum[3]
      chordPty[ii+12, iiplus+12] <- ptySum[4]
    }
  }
}

# Normalization
chordPty  <- t(t(chordPty) / colSums(chordPty))
chordPty0 <- chordPty0 / sum(chordPty0)

# Saving results
if(tying) {
  save(chordPty, file="TrainedParameters/chordModel.tying.Rdata")
  save(chordPty0, file="TrainedParameters/chordModel0.tying.Rdata")
} else {
  save(chordPty, file="TrainedParameters/chordModel.noTying.Rdata")
  save(chordPty0, file="TrainedParameters/chordModel0.noTying.Rdata")
}

