# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Settings/training.R")
source("Datasets/datasets.R")
source("Cross-entropy/crossEntropyFunctions.R")

# neighbourPties.nonsmooth = matrix(1, 2, 4)
# for(analyzedFile in mutopiaFiles.training)
# {
#   cat("Filename =", analyzedFile, "\n")
#   load(paste("Datasets/Mutopia/Processed/", analyzedFile, sep=""))
# 
#   previousState = rbind(rep(0, ncol(dataMatrix)), dataMatrix[1:87,])
#   previousPreviousState = rbind(rep(0, ncol(dataMatrix)), rep(0, ncol(dataMatrix)), dataMatrix[1:86,])
#   for(kk in 0:1) for(ll in 0:1) for(mm in 0:1)
#     neighbourPties.nonsmooth[ll+1, mm*2+kk+1] = neighbourPties.nonsmooth[ll+1, mm*2+kk+1] + length(which((previousState == kk) & (dataMatrix == ll) & (previousPreviousState == mm)))
# }

trainNeighbourModel = function(smoothingFactor=1)
{
  neighbourPties = neighbourPties.nonsmooth + smoothingFactor
  neighbourPties = t(t(neighbourPties) / colSums(neighbourPties))
  save(neighbourPties, file="TrainedParameters/neighbourModel.Rdata")
  return(neighbourPties)
}

crossEntropyForSmoothingFactor = function(parameters)
{
  cat(" +", paste(rep("—", 160), collapse=""), "\n | Parameters = ", parameters[1], ", ", parameters[2], "\n", sep="")
  trainNeighbourModel(smoothingFactor=exp(parameters[1]))
  return(averageLikelihoodFunction(fudgeFactors=parameters[2], models="N"))
}

bestSmoothingFactor = optim(par=c(1,1), fn=crossEntropyForSmoothingFactor, lower=0)

# Use the default parameters
trainNeighbourModel(bestSmoothingFactor$par[1])
