# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Settings/training.R")

quantizationLevels <- 500
maxS = 0.04
# maxS = 1

cat("Training output probabilities... ")
GT = S = matrix(NA, 88, 0)
for(filename in rwcFiles)
{
#   cat(filename, ":\n", sep="")
  load(paste("Datasets/RWC/NMF/", filename, sep=""))
  S = cbind(S, audiodata / maxS)
  load(paste("Datasets/RWC/", filename, sep=""))
  GT = cbind(GT, t(dataMatrix[,2:89]))
}

onValues  <- S[GT == 1]
offValues <- S[GT == 0]

onHist  <- hist(onValues,  breaks=seq(0, maxS, length.out=quantizationLevels+1), plot=F)$density
offHist <- hist(offValues, breaks=seq(0, maxS, length.out=quantizationLevels+1), plot=F)$density

onProbability  <- onHist / sum(onHist)
offProbability <- offHist / sum(offHist)

save(onProbability,  file="TrainedParameters/onProbability.Rdata")
save(offProbability, file="TrainedParameters/offProbability.Rdata")
cat("done!\n")

if(plotResults)
{
  crossPointX = which(onProbability > offProbability)[1]
  crossPointY = onProbability[crossPointX]
  crossPointX = seq(0,0.04,length.out=quantizationLevels)[crossPointX]
  if(plotToPDF)
  {
    pdf(paste("Plots/salienceProbs.pdf", sep=""), width=imageWidth/2.54, height=6/2.54)
    par(cex=0.5)
  }
  else
    X11()
  matplot(x=seq(0,0.04,length.out=quantizationLevels), y=cbind(onProbability, offProbability), type="l", ylab="Probability", xlab="Detected activity", log="xy", lty=1)
  points(x=crossPointX, y=crossPointY)
  text(x=crossPointX, y=crossPointY+5e-2, paste("O =",round(crossPointX,4)))
  if(plotToPDF)
    dev.off()
}
