# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

mutopiaFiles.testing = unlist(read.table("Datasets/Mutopia/mutopiaFiles.testing.txt", stringsAsFactors=FALSE), use.names=FALSE)

mismatchCheck.old = function(filename)
{
  cat(filename, ": loading...\n", sep="")
  processedFilename = gsub("/", "_", filename)
  processedFilename = gsub("\\.mid", "", processedFilename)
  load(paste("Datasets/Mutopia/Processed/", processedFilename, ".txt.Rdata", sep=""))
#   cat(filename, ": getting max frame position\n", sep="")
  framePos = read.table(paste("Datasets/Mutopia/FramePos/", processedFilename, ".csv", sep=""), sep=",")[,1]
  lastFrame = max(framePos)
  
#   processedFilename = gsub("\\.", "_", processedFilename)
#   load(paste("Datasets/Mutopia/NMF/", processedFilename, ".Rdata", sep=""))
# 
#   if(ncol(audiodata) > ncol(dataMatrix))
#     cat("Size mismatch:", ncol(audiodata), "vs", ncol(dataMatrix), "\n")
#   if(ncol(dataMatrix) > ncol(audiodata))
#     cat("Size mismatch:", ncol(audiodata), "vs", ncol(dataMatrix), "\n")

  return(c(lastFrame, ncol(dataMatrix)))
}

mismatchCheck = function(fileNr)
{
  filename = mutopiaFiles.testing[fileNr]
  processedFilename = gsub("/", "_", filename)
  processedFilename = gsub("\\.mid", "", processedFilename)

  cat(filename, ": getting max frame position\n", sep="")
  framePos = read.table(paste("Datasets/Mutopia/FramePos/", processedFilename, ".csv", sep=""), sep=",")[,1]
  lastFrame = max(framePos)
  
  cat(filename, ": getting audio length\n", sep="")
  audioLength = read.table("Datasets/Mutopia/filelengths.txt")[fileNr,1]

  return(c(audioLength, lastFrame))
}

library("multicore")
results = matrix(unlist(mclapply(1:100, mismatchCheck)), nrow=2)

par(mar=c(40,4,4,2)+0.1)
barplot(results[1,] / results[2,], names.arg=mutopiaFiles.testing, las=2)
abline(h=1, col="red")
