# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Datasets/datasets.R")
source("Settings/audio.R", local=TRUE)
source("Auxiliary/PRF.R", local=TRUE)
source("Training/probabilityDefinitions.R", local=TRUE)
source("Settings/training.R", local=TRUE)
source("Auxiliary/fancyOutput.R", local=TRUE)

## The following values were found experimentally (but only for 2 files)
expFactor = 0.5404476 #0.8
acousticFudgeFactor = 50 #50

# allResultsFullModel = lapply(mutopiaFiles.testing[1], function(filename) {
filename = mutopiaFiles.testing[1]
fileNr = 1

  cat("Loading ", filename, "\n", sep="")
  load(paste("Datasets/Mutopia/NMF/", sub(".txt", "", filename), sep=""))
  load(paste("Datasets/Mutopia/Processed/", filename, sep=""))
  S = audiodata
  if(ncol(S) > maxLength)
    S = S[,1:maxLength]
  S = S^nonlinearityFactor

  source("Experiments.Audio/precalculateTransitionMatrix.R", local=TRUE)

  load(file="TrainedParameters/onProbabilities.Rdata")
  load(file="TrainedParameters/offProbabilities.Rdata")
  onProbabilities  = log(onProbabilities)
  offProbabilities = log(offProbabilities)

  source("Experiments.Audio/precalculateOutputMatrix.R", local=TRUE)
  source("Experiments.Audio/performModifiedFrontierAlgorithm.R", local=TRUE)
  fmeas = PRF.onsets(resultingMatrix, dataMatrix[,1:ncol(S)])

  # Below is calculation of PRF without decoding (e.g. for bernoulliFudgeFactor = 1)
  #PRF.onsets(t(reducedCombinationMatrix[sapply(1:320, function(frameNr) getCombinationIndices(frameNr, indexTranslator)[which.max(outputPties[,frameNr])]),]), dataMatrix[,1:ncol(S)]) 

#   return(PRF.onsets(resultingMatrix, dataMatrix[,1:ncol(S)]))
# })

#save(allResultsFullModel, file="Results/audio.results-FullModel3.Rdata")


### This is just for temporary plotting of results: #############################
source("Experiments.Audio/getThresholdingResults.R")
threshold = 0.1987277 #0.1994822
resultingMatrix.threshold = ifelse(audiodata > threshold, 1, 0)

cat("Full model   =", paste(round(100*PRF.onsets(resultingMatrix[,1:ncol(S)], dataMatrix[,1:ncol(S)]), 3), "%", sep=""), "\n")
cat("Thresholding =", paste(round(100*PRF.onsets(resultingMatrix.threshold[,1:ncol(S)], dataMatrix[,1:ncol(S)]), 3), "%", sep=""), "\n")

pdf("results_fullmodel_3.pdf", width=10/2.54, height=6/2.54); par(cex=0.5, mar=c(5, 4, 0, 0) + 0.1)
image(x=1:ncol(resultingMatrix), y=1:88, t(resultingMatrix), col=gray.colors(256,1,0,1), xlab="Frame number", ylab="Piano key number"); dev.off()
pdf("results_thresholding_3.pdf", width=10/2.54, height=6/2.54); par(cex=0.5, mar=c(5, 4, 0, 0) + 0.1)
image(x=1:ncol(S), y=1:88, t(resultingMatrix.threshold[,1:ncol(S)]), col=gray.colors(256,1,0,1), xlab="Frame number", ylab="Piano key number"); dev.off()
pdf("results_saliences_3.pdf", width=10/2.54, height=6/2.54); par(cex=0.5, mar=c(5, 4, 0, 0) + 0.1)
image(x=1:ncol(S), y=1:88, t(S[,1:ncol(S)]), col=gray.colors(256,1,0,1), xlab="Frame number", ylab="Piano key number"); dev.off()
pdf("results_reference_3.pdf", width=10/2.54, height=6/2.54); par(cex=0.5, mar=c(5, 4, 0, 0) + 0.1)
image(x=1:ncol(S), y=1:88, t(dataMatrix[,1:ncol(S)]), col=gray.colors(256,1,0,1), xlab="Frame number", ylab="Piano key number"); dev.off()
##################################################################################
