# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

library("multicore")

source("Settings/training.R")
source("Settings/audio.R")
source("Datasets/datasets.R")

solutionSpaceCoverage = function(filename, numberOfPeakCandidates)
{
  cat(filename, "\n")
  load(paste("Datasets/Mutopia/NMF/", gsub("\\.", "_", sub("\\.txt\\.Rdata", "", filename)), ".Rdata", sep=""))
  load(paste("Datasets/Mutopia/Processed/", filename, sep=""))
  S = audiodata
  if(ncol(S) > maxLength)
    S = S[,1:maxLength]
  S = S^nonlinearityFactor
  dataMatrix = dataMatrix[,1:ncol(S)]

  smoothedS = S
  expFactor = 0.5
  for(ii in 2:ncol(S))
    smoothedS[,ii] = smoothedS[,ii] + expFactor * smoothedS[,ii-1]

  peakMatrix <- matrix(0, ncol(S), numberOfPeakCandidates)
  for(timeSlice in 1:ncol(S))
    peakMatrix[timeSlice, ] <- sort(smoothedS[, timeSlice], index.return=T, decreasing=T)$ix[1:numberOfPeakCandidates]
  return(sum(sapply(1:ncol(S), function(timeSlice) sum(dataMatrix[peakMatrix[timeSlice, ],timeSlice] == 1))) * 100 / sum(dataMatrix))
}

averageCoverages = sapply(1:12, function(peaks) mean(unlist(mclapply(as.vector(mutopiaFiles.testing), function(filename) solutionSpaceCoverage(filename, peaks)))))
