# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

library('multicore')

source("Auxiliary/PRF.R")
# source("Datasets/datasets.R")

source("Experiments.Audio/getThresholdingResults.R")

mutopiaFiles.testing = unlist(read.table("Datasets/Mutopia/mutopiaFiles.testing.txt", stringsAsFactors=FALSE), use.names=FALSE)
instrumentsUsed = factor(c("Piano", "Piano", "Piano", "Acoustic guitar (nylon)", "Piano",
  "Harpsichord", "Piano", "Violin", "Harpsichord", "Cello",
  "Acoustic guitar (nylon)", "Violin/viola/cello", "Piano", "Church organ/Tuba", "Church organ/Trombone",
  "Church organ/Trombone", "Recorder/Pan flute", "Recorder/Oboe/Pan flute", "Piano", "Piano",
  "Piano", "Harpsichord", "Harpsichord", "Harpsichord", "Pan flute",
  "Piano", "Voice 'aah'/Piano", "Piano", "Rock organ/Reed organ", "Piano",
  "Piano", "Violin/Viola/Cello", "Violin/Grand piano", "Violin/French horn/Piano", "Piano",
  "Piano", "Guitar", "Clarinet", "Piano", "Piano",
  "Church organ", "Piano", "Piano", "Piano", "Piano",
  "Voice 'ooh'", "Acoustic guitar (nylon)", "Piano", "Piano", "Piano",
  "Piano", "Harpsichord", "Trumpet/Timpani", "Harpsichord/Oboe", "Piano",
  "Acoustic guitar (nylon)", "Acoustic guitar (nylon)", "Acoustic guitar (nylon)", "Acoustic guitar (nylon)", "Piano",
  "Piano", "Acoustic guitar (nylon)", "Piano", "Piano", "Oboe",
  "Piano", "Acoustic guitar (nylon)", "Piano/Flute/Triangle", "Piano",
  "Piano", "Piano", "Cello/Mandolin/Acoustic guitar (steel)/Piano", "Piano", "Piano",
  "Piano", "Piano", "Church organ", "Piano", "Trombone/Piano",
  "Piano/Trumpet", "Oboe/Clarinet/French horn/Bassoon", "Piano", "Piano", "Piano",
  "Piano", "Acoustic guitar (nylon)", "Piano", "Voice 'ooh'", "Pan flute/Recorder",
  "Church organ", "Shamisen", "Piano", "Piano", "Piano",
  "Piano", "Piano", "Piano", "Tremolo strings", "Piano", "Voice 'aah'"))

# results = matrix(unlist(mclapply(mutopiaFiles.testing, thresholdingResults)), nrow=5)
# 
# instrumentResults = sapply(levels(instrumentsUsed), function(x) mean(results[5, instrumentsUsed == x]))
# instrumentResults = sort(instrumentResults, index.return=TRUE)
#
# par(mar=c(20,4,4,2)+0.1)
# barplot(instrumentResults$x*100, names.arg=paste(levels(instrumentsUsed)[instrumentResults$ix], " (", table(instrumentsUsed)[instrumentResults$ix], ")", sep=""), las=2, ylim=c(0,100))
# abline(h=mean(results[5,])*100)
# text(x=6, y=mean(results[5,])*100+2, paste(round(mean(results[5,])*100, 2), "%", sep=""))
#
# X11()
# par(mar=c(20,4,4,2)+0.1)
# barplot(results[5,]*100, las=2, ylim=c(0,100), names.arg=mutopiaFiles.testing)
# abline(h=mean(results[5,])*100)
# text(x=6, y=mean(results[5,])*100+2, paste(round(mean(results[5,])*100, 2), "%", sep=""))

# bestThreshold = optim(0.2, function(x) getSingleResults(mutopiaFiles.testing, x), method="L-BFGS-B", lower=0, upper=1, control=list(fnscale=-1))
# $par
# [1] 0.1994822
# 
# $value
# [1] 0.7012549
# 
# $counts
# function gradient
#       36       36
# allResultsThresholding = matrix(unlist(mclapply(mutopiaFiles.testing, function(filename) thresholdingResults.givenThreshold(filename, threshold=0.1994822))), nrow=3)
# save(allResultsThresholding, file="Results/audio.results-Thresholding.Rdata")

# allThresholdResults = sapply(seq(0, 1, length.out=100), function(x) getSingleResults(mutopiaFiles.testing, x))

allResultsThresholding = matrix(unlist(mclapply(mutopiaFiles.testing, function(filename) thresholdingResults.givenThreshold(filename, threshold=0.0299))), nrow=3)
save(allResultsThresholding, file="Results/audio.results-ThresholdingML.Rdata")
