# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Datasets/datasets.R")
source("Cross-entropy/crossEntropyFunctions.R")

getAllResults = function(models, bins="all", interpolationMethod)
{
  if(!(models %in% c("Bernoulli", "PBernoulli")))
  {
    load(paste("TrainedParameters/fudgeFactors.", models, ".", interpolationMethod, ".Rdata", sep=""))  # load the trained fudge factors
    return(averageLikelihoodFunction(fudgeFactors$par, dataset=mutopiaFiles.testing, models=models, silent=FALSE, bins=bins, interpolation=interpolationMethod))
  }
  else
    return(averageLikelihoodFunction(c(), dataset=mutopiaFiles.testing, models=models, silent=FALSE, bins=bins, interpolation=NULL))
}

models = c("Bernoulli", "PBernoulli", "H", "HC", "D", "V", "P", "N", "DN", "HCV", "HCDPN", "HCDVPN")
types  = c("all", "onsets", "offsets", "changes", "silence", "notes")

calculateAll = function(interpolationMethod)
{
  crossEntropies = matrix(NA, length(models), length(types))
#   load(file=paste("Results/crossEntropies.", interpolationMethod, ".Rdata", sep=""))
  for(typeNr in seq_along(types))
    for(modelNr in seq_along(models))
  {
    crossEntropies[modelNr, typeNr] = getAllResults(models=models[modelNr], bins=types[typeNr], interpolationMethod)
    save(crossEntropies, file=paste("Results/crossEntropies.", interpolationMethod, ".Rdata", sep=""))
  }
  return(crossEntropies)
}

crossEntropies.loglinear = calculateAll("loglinear")
crossEntropies.linear = calculateAll("linear")
