# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

load("Results/Old/crossEntropies.linear.Rdata")
entropies_linear = crossEntropies[,c(1,2,5,6)]
load("Results/Old/crossEntropies.loglinear.Rdata")
entropies_loglinear = crossEntropies[,c(1,2,5,6)]
entropies_loglinear[3:8,] = entropies_linear[3:8,]

models = c("Bernoulli", "PBernoulli", "H", "HC", "D", "V", "P", "N", "DN", "HCV", "HCDPN", "HCDVPN")

lapply(c("linear", "loglinear"), function(interpolationMethod) {
  if(interpolationMethod == "linear") {
    crossEntropies = entropies_linear
  } else
    crossEntropies = entropies_loglinear
  lapply(c(FALSE, TRUE), function(perplexity)
  {
    types  = c("all pitches", "onsets only", "silence", "notes")
    barColors    = c("dark gray", "black", "black", "white")
    barDensities = c(NA, 50, 50, NA)
    barAngles    = c(NA, 45, -45, NA)

    if(perplexity)
      dataToPlot = 2^as.vector(crossEntropies)
    else
      dataToPlot = as.vector(crossEntropies)  # in milibits
    spacing = c(0.2, rep(c(rep(0.2, length(models)-1), 1), length(types)-1), rep(0.2, length(models)-1))
    barCenters = 0.25 + c(seq(1:length(dataToPlot)) - 1 + cumsum(spacing))

    pdf(paste("Plots/paraCrossEntropies.", interpolationMethod, ".", ifelse(perplexity, "perplexity", "entropy"), ".pdf", sep=""), height=10/2.54, width=16/2.54)
    par(cex=0.5)  # smaller text
    par(mar=c(5,4,4,2)+0.1)
      barplot(dataToPlot, space=spacing, names.arg=rep(c(models), length(types)), las=2, ylab=ifelse(perplexity, "Pitch paraperplexity", "Pitch contextual cross-entropy [b]"), col=rep(barColors, each=length(models)), ylim=c(0, ifelse(perplexity, 20, 6)), density=rep(barDensities, each=length(models)), angle=rep(barAngles, each=length(models)))
#      text(y=barCenters, x=dataToPlot+ifelse(perplexity, 0.2, 0.1), paste(signif(dataToPlot, 3), ifelse(perplexity, "", " b"), sep=""), pos=4)
      abline(h=1:7, lty=3)
      abline(h=0, lty=1)
      legend(ifelse(perplexity, 20, 1), 5.5, types, fill=barColors, density=barDensities, angle=barAngles, bg="white")
    dev.off()
  })
})

pdf("Plots/paraCrossEntropies.compare.pdf", width=16/2.54, height=10/2.54)
  par(cex=0.5)
  barplot(1000 * (entropies_linear[9:12,1] - entropies_loglinear[9:12,1]), ylim=c(0,500), ylab="Pitch contextual cross-entropy [mb]", names.arg=models[9:12], las=2)
dev.off()

