# -----------------------------------------------------------------
# 
#      MULTIPLE PITCH ANALYSIS WITH DYNAMIC BAYESIAN NETWORKS
# 
# This package contains the code for multiple pitch analysis using
# methods described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Dynamic Bayesian
# networks for symbolic polyphonic pitch modelling,” INRIA
# Technical Report RT-430, 2012,
# URL: http://hal.inria.fr/hal-00728771/en
# 
# This code has been written by Stanisław Raczyński at INRIA, France.
# Contact information: stanislaw.raczynski@inria.fr
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# -----------------------------------------------------------------

source("Datasets/datasets.R")
source("Settings/training.R")
source("Interpolation/optimizeCoefficients.R")

# Single models
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="H", interpolation="loglinear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="HC", interpolation="loglinear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="D", interpolation="loglinear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="V", interpolation="loglinear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="P", interpolation="loglinear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="N", interpolation="loglinear")
# 
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="H", interpolation="linear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="HC", interpolation="linear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="D", interpolation="linear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="V", interpolation="linear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="P", interpolation="linear")
# fudgeFactors = optimizeCoefficients(initialValues=c(1), models="N", interpolation="linear")

# Double models
fudgeFactors = optimizeCoefficients(initialValues=c(1,1), models="HCV", interpolation="loglinear")
fudgeFactors = optimizeCoefficients(initialValues=c(1,1), models="HCV", interpolation="linear")
fudgeFactors = optimizeCoefficients(initialValues=c(1,1), models="DN", interpolation="loglinear")
fudgeFactors = optimizeCoefficients(initialValues=c(1,1), models="DN", interpolation="linear")

# Triple models
# there are none

# Quadruple models
fudgeFactors = optimizeCoefficients(initialValues=c(1,1,1,1), models="HCDPN", interpolation="loglinear")
fudgeFactors = optimizeCoefficients(initialValues=c(1,1,1,1), models="HCDPN", interpolation="linear")

# Quintuple models
fudgeFactors = optimizeCoefficients(initialValues=c(1,1,1,1,1), models="HCDVPN", interpolation="loglinear")
fudgeFactors = optimizeCoefficients(initialValues=c(1,1,1,1,1), models="HCDVPN", interpolation="linear")
